changeset 64787:d3ba08ae337e

(inferior-scheme-mode-hook, inferior-scheme-mode, scheme-prev-l/c-dir/file): Fix typos in docstrings.
author Juanma Barranquero <lekktu@gmail.com>
date Mon, 08 Aug 2005 18:00:19 +0000
parents 871d0952aeb3
children 8960bd28d1ee
files lisp/cmuscheme.el
diffstat 1 files changed, 7 insertions(+), 7 deletions(-) [+]
line wrap: on
line diff
--- a/lisp/cmuscheme.el	Mon Aug 08 17:53:51 2005 +0000
+++ b/lisp/cmuscheme.el	Mon Aug 08 18:00:19 2005 +0000
@@ -26,7 +26,7 @@
 
 ;;; Commentary:
 
 ;;    This is a customisation of comint-mode (see comint.el)
 ;;
 ;; Written by Olin Shivers (olin.shivers@cs.cmu.edu). With bits and pieces
 ;; lifted from scheme.el, shell.el, clisp.el, newclisp.el, cobol.el, et al..
@@ -106,7 +106,7 @@
 ;;;============================================================================
 
 (defcustom inferior-scheme-mode-hook nil
-  "*Hook for customising inferior-scheme mode."
+  "*Hook for customizing inferior-scheme mode."
   :type 'hook
   :group 'cmuscheme)
 
@@ -172,7 +172,7 @@
 
 A Scheme process can be fired up with M-x run-scheme.
 
-Customisation: Entry to this mode runs the hooks on comint-mode-hook and
+Customization: Entry to this mode runs the hooks on comint-mode-hook and
 inferior-scheme-mode-hook (in that order).
 
 You can send text to the inferior Scheme process from other buffers containing
@@ -201,7 +201,7 @@
 Paragraphs are separated only by blank lines.  Semicolons start comments.
 If you accidentally suspend your process, use \\[comint-continue-subjob]
 to continue it."
-  ;; Customise in inferior-scheme-mode-hook
+  ;; Customize in inferior-scheme-mode-hook
   (setq comint-prompt-regexp "^[^>\n]*>+ *") ; OK for cscheme, oaklisp, T,...
   (scheme-mode-variables)
   (setq mode-line-process '(":%s"))
@@ -432,8 +432,8 @@
 (defvar scheme-prev-l/c-dir/file nil
   "Caches the last (directory . file) pair.
 Caches the last pair used in the last `scheme-load-file' or
-`scheme-compile-file' command. Used for determining the default in the
-next one.")
+`scheme-compile-file' command.  Used for determining the default
+in the next one.")
 
 (defun scheme-load-file (file-name)
   "Load a Scheme file FILE-NAME into the inferior Scheme process."
@@ -525,7 +525,7 @@
   (save-window-excursion
     (run-scheme (read-string "Run Scheme: " scheme-program-name))))
 
 ;;; Do the user's customisation...
 
 (defcustom cmuscheme-load-hook nil
   "This hook is run when cmuscheme is loaded in.
@@ -26,7 +26,7 @@
 ;;; Commentary:
 
-;;    This is a customisation of comint-mode (see comint.el)
+;;    This is a customization of comint-mode (see comint.el)
 ;;
 ;; Written by Olin Shivers (olin.shivers@cs.cmu.edu). With bits and pieces
@@ -525,7 +525,7 @@
     (run-scheme (read-string "Run Scheme: " scheme-program-name))))
 
-;;; Do the user's customisation...
+;;; Do the user's customization...
 
 (defcustom cmuscheme-load-hook nil